@@ -20,7 +20,7 @@ from jinja2 import __version__ as jinja2_version
 import jinjafx, os, io, sys, socket, signal, threading, yaml, json, base64, time, datetime
 import re, argparse, zipfile, hashlib, traceback, glob, hmac, uuid, struct, binascii, gzip, requests
 
-__version__ = '22.1.6'
+__version__ = '22.1.7'
 
 try:
   from ansible.constants import DEFAULT_VAULT_ID_MATCH
@@ -325,14 +325,8 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
                 if y != None:
                   gvars.update(y)
   
-              if 'jinja2_extensions' in gvars:
-                gvars['jinja2_extensions'].append('jinjafx_extension.JinjaFxExtension')
-
-              else:
-                gvars['jinja2_extensions'] = ['jinjafx_extension.JinjaFxExtension']
-
               st = round(time.time() * 1000)
-              outputs = jinjafx.JinjaFx().jinjafx(template, data, gvars, 'Output', [base + '/extensions'])
+              outputs = jinjafx.JinjaFx().jinjafx(template, data, gvars, 'Output')
               ocount = 0
   
               jsr = {
